==> haskell-cipher-aes128-0.7.0.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes128
version: 0.7.0.3
id: cipher-aes128-0.7.0.3-KZRh36IRPZaDi32G4X425P
key: cipher-aes128-0.7.0.3-KZRh36IRPZaDi32G4X425P
license: BSD-3-Clause
copyright: Thomas M. DuBuisson
maintainer: thomas.dubuisson@gmail.com
author: Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage: https://github.com/TomMD/cipher-aes128
synopsis: AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.
category: Cryptography
abi: bf2a1d9215074c4c7b0825b7b3d257db
exposed: True
exposed-modules:
    Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cipher-aes128-0.7.0.3
hs-libraries: HScipher-aes128-0.7.0.3-KZRh36IRPZaDi32G4X425P
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l=04b47272348e9aa5648e546d18028ecd
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
haddock-interfaces: /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes128-0.7.0.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes128
version: 0.7.0.3
id: cipher-aes128-0.7.0.3-AjBklnlJqxQ3rMxO2aZy1C
key: cipher-aes128-0.7.0.3-AjBklnlJqxQ3rMxO2aZy1C
license: BSD-3-Clause
copyright: Thomas M. DuBuisson
maintainer: thomas.dubuisson@gmail.com
author: Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage: https://github.com/TomMD/cipher-aes128
synopsis: AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.
category: Cryptography
abi: 370257fc6d4089146f14448e70bf361b
exposed: True
exposed-modules:
    Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cipher-aes128-0.7.0.3
hs-libraries: HScipher-aes128-0.7.0.3-AjBklnlJqxQ3rMxO2aZy1C
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x=b38ee8fa4c1e132a024035423192fcff
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
haddock-interfaces: /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
